# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBillingAccountInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'BTAddressInfo',
        'card': 'BTCardInfo',
        'created_at': 'datetime',
        'account_balance': 'int',
        'state': 'int',
        'stripe_id': 'str',
        'company': 'BTCompanyInfo',
        'pro_monthly_enabled': 'bool',
        'owner': 'BTUserSummaryInfo',
        'zuora_id': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str',
        'name': 'str'
    }

    attribute_map = {
        'address': 'address',
        'card': 'card',
        'created_at': 'createdAt',
        'account_balance': 'accountBalance',
        'state': 'state',
        'stripe_id': 'stripeId',
        'company': 'company',
        'pro_monthly_enabled': 'proMonthlyEnabled',
        'owner': 'owner',
        'zuora_id': 'zuoraId',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef',
        'name': 'name'
    }

    def __init__(self, address=None, card=None, created_at=None, account_balance=None, state=None, stripe_id=None, company=None, pro_monthly_enabled=None, owner=None, zuora_id=None, id=None, href=None, view_ref=None, name=None):  # noqa: E501
        """BTBillingAccountInfo - a model defined in OpenAPI"""  # noqa: E501

        self._address = None
        self._card = None
        self._created_at = None
        self._account_balance = None
        self._state = None
        self._stripe_id = None
        self._company = None
        self._pro_monthly_enabled = None
        self._owner = None
        self._zuora_id = None
        self._id = None
        self._href = None
        self._view_ref = None
        self._name = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if card is not None:
            self.card = card
        if created_at is not None:
            self.created_at = created_at
        if account_balance is not None:
            self.account_balance = account_balance
        if state is not None:
            self.state = state
        if stripe_id is not None:
            self.stripe_id = stripe_id
        if company is not None:
            self.company = company
        if pro_monthly_enabled is not None:
            self.pro_monthly_enabled = pro_monthly_enabled
        if owner is not None:
            self.owner = owner
        if zuora_id is not None:
            self.zuora_id = zuora_id
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref
        if name is not None:
            self.name = name

    @property
    def address(self):
        """Gets the address of this BTBillingAccountInfo.  # noqa: E501


        :return: The address of this BTBillingAccountInfo.  # noqa: E501
        :rtype: BTAddressInfo
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this BTBillingAccountInfo.


        :param address: The address of this BTBillingAccountInfo.  # noqa: E501
        :type: BTAddressInfo
        """

        self._address = address

    @property
    def card(self):
        """Gets the card of this BTBillingAccountInfo.  # noqa: E501


        :return: The card of this BTBillingAccountInfo.  # noqa: E501
        :rtype: BTCardInfo
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this BTBillingAccountInfo.


        :param card: The card of this BTBillingAccountInfo.  # noqa: E501
        :type: BTCardInfo
        """

        self._card = card

    @property
    def created_at(self):
        """Gets the created_at of this BTBillingAccountInfo.  # noqa: E501


        :return: The created_at of this BTBillingAccountInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTBillingAccountInfo.


        :param created_at: The created_at of this BTBillingAccountInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def account_balance(self):
        """Gets the account_balance of this BTBillingAccountInfo.  # noqa: E501


        :return: The account_balance of this BTBillingAccountInfo.  # noqa: E501
        :rtype: int
        """
        return self._account_balance

    @account_balance.setter
    def account_balance(self, account_balance):
        """Sets the account_balance of this BTBillingAccountInfo.


        :param account_balance: The account_balance of this BTBillingAccountInfo.  # noqa: E501
        :type: int
        """

        self._account_balance = account_balance

    @property
    def state(self):
        """Gets the state of this BTBillingAccountInfo.  # noqa: E501


        :return: The state of this BTBillingAccountInfo.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTBillingAccountInfo.


        :param state: The state of this BTBillingAccountInfo.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def stripe_id(self):
        """Gets the stripe_id of this BTBillingAccountInfo.  # noqa: E501


        :return: The stripe_id of this BTBillingAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._stripe_id

    @stripe_id.setter
    def stripe_id(self, stripe_id):
        """Sets the stripe_id of this BTBillingAccountInfo.


        :param stripe_id: The stripe_id of this BTBillingAccountInfo.  # noqa: E501
        :type: str
        """

        self._stripe_id = stripe_id

    @property
    def company(self):
        """Gets the company of this BTBillingAccountInfo.  # noqa: E501


        :return: The company of this BTBillingAccountInfo.  # noqa: E501
        :rtype: BTCompanyInfo
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this BTBillingAccountInfo.


        :param company: The company of this BTBillingAccountInfo.  # noqa: E501
        :type: BTCompanyInfo
        """

        self._company = company

    @property
    def pro_monthly_enabled(self):
        """Gets the pro_monthly_enabled of this BTBillingAccountInfo.  # noqa: E501


        :return: The pro_monthly_enabled of this BTBillingAccountInfo.  # noqa: E501
        :rtype: bool
        """
        return self._pro_monthly_enabled

    @pro_monthly_enabled.setter
    def pro_monthly_enabled(self, pro_monthly_enabled):
        """Sets the pro_monthly_enabled of this BTBillingAccountInfo.


        :param pro_monthly_enabled: The pro_monthly_enabled of this BTBillingAccountInfo.  # noqa: E501
        :type: bool
        """

        self._pro_monthly_enabled = pro_monthly_enabled

    @property
    def owner(self):
        """Gets the owner of this BTBillingAccountInfo.  # noqa: E501


        :return: The owner of this BTBillingAccountInfo.  # noqa: E501
        :rtype: BTUserSummaryInfo
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this BTBillingAccountInfo.


        :param owner: The owner of this BTBillingAccountInfo.  # noqa: E501
        :type: BTUserSummaryInfo
        """

        self._owner = owner

    @property
    def zuora_id(self):
        """Gets the zuora_id of this BTBillingAccountInfo.  # noqa: E501


        :return: The zuora_id of this BTBillingAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._zuora_id

    @zuora_id.setter
    def zuora_id(self, zuora_id):
        """Sets the zuora_id of this BTBillingAccountInfo.


        :param zuora_id: The zuora_id of this BTBillingAccountInfo.  # noqa: E501
        :type: str
        """

        self._zuora_id = zuora_id

    @property
    def id(self):
        """Gets the id of this BTBillingAccountInfo.  # noqa: E501


        :return: The id of this BTBillingAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTBillingAccountInfo.


        :param id: The id of this BTBillingAccountInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTBillingAccountInfo.  # noqa: E501


        :return: The href of this BTBillingAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTBillingAccountInfo.


        :param href: The href of this BTBillingAccountInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTBillingAccountInfo.  # noqa: E501


        :return: The view_ref of this BTBillingAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTBillingAccountInfo.


        :param view_ref: The view_ref of this BTBillingAccountInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    @property
    def name(self):
        """Gets the name of this BTBillingAccountInfo.  # noqa: E501


        :return: The name of this BTBillingAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBillingAccountInfo.


        :param name: The name of this BTBillingAccountInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBillingAccountInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUpgradeOnDemandParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'notification_id': 'str',
        'target_version': 'int',
        'connection_id': 'str'
    }

    attribute_map = {
        'notification_id': 'notificationId',
        'target_version': 'targetVersion',
        'connection_id': 'connectionId'
    }

    def __init__(self, notification_id=None, target_version=None, connection_id=None):  # noqa: E501
        """BTUpgradeOnDemandParams - a model defined in OpenAPI"""  # noqa: E501

        self._notification_id = None
        self._target_version = None
        self._connection_id = None
        self.discriminator = None

        if notification_id is not None:
            self.notification_id = notification_id
        if target_version is not None:
            self.target_version = target_version
        if connection_id is not None:
            self.connection_id = connection_id

    @property
    def notification_id(self):
        """Gets the notification_id of this BTUpgradeOnDemandParams.  # noqa: E501


        :return: The notification_id of this BTUpgradeOnDemandParams.  # noqa: E501
        :rtype: str
        """
        return self._notification_id

    @notification_id.setter
    def notification_id(self, notification_id):
        """Sets the notification_id of this BTUpgradeOnDemandParams.


        :param notification_id: The notification_id of this BTUpgradeOnDemandParams.  # noqa: E501
        :type: str
        """

        self._notification_id = notification_id

    @property
    def target_version(self):
        """Gets the target_version of this BTUpgradeOnDemandParams.  # noqa: E501


        :return: The target_version of this BTUpgradeOnDemandParams.  # noqa: E501
        :rtype: int
        """
        return self._target_version

    @target_version.setter
    def target_version(self, target_version):
        """Sets the target_version of this BTUpgradeOnDemandParams.


        :param target_version: The target_version of this BTUpgradeOnDemandParams.  # noqa: E501
        :type: int
        """

        self._target_version = target_version

    @property
    def connection_id(self):
        """Gets the connection_id of this BTUpgradeOnDemandParams.  # noqa: E501


        :return: The connection_id of this BTUpgradeOnDemandParams.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this BTUpgradeOnDemandParams.


        :param connection_id: The connection_id of this BTUpgradeOnDemandParams.  # noqa: E501
        :type: str
        """

        self._connection_id = connection_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUpgradeOnDemandParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentInfoAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'document_thumbnail_element_id': 'str',
        'duplicate_name_violation_error': 'str',
        'beta_capability_ids': 'list[str]',
        'is_upgraded_to_latest_version': 'bool'
    }

    attribute_map = {
        'document_thumbnail_element_id': 'documentThumbnailElementId',
        'duplicate_name_violation_error': 'duplicateNameViolationError',
        'beta_capability_ids': 'betaCapabilityIds',
        'is_upgraded_to_latest_version': 'isUpgradedToLatestVersion'
    }

    def __init__(self, document_thumbnail_element_id=None, duplicate_name_violation_error=None, beta_capability_ids=None, is_upgraded_to_latest_version=None):  # noqa: E501
        """BTDocumentInfoAllOf - a model defined in OpenAPI"""  # noqa: E501

        self._document_thumbnail_element_id = None
        self._duplicate_name_violation_error = None
        self._beta_capability_ids = None
        self._is_upgraded_to_latest_version = None
        self.discriminator = None

        if document_thumbnail_element_id is not None:
            self.document_thumbnail_element_id = document_thumbnail_element_id
        if duplicate_name_violation_error is not None:
            self.duplicate_name_violation_error = duplicate_name_violation_error
        if beta_capability_ids is not None:
            self.beta_capability_ids = beta_capability_ids
        if is_upgraded_to_latest_version is not None:
            self.is_upgraded_to_latest_version = is_upgraded_to_latest_version

    @property
    def document_thumbnail_element_id(self):
        """Gets the document_thumbnail_element_id of this BTDocumentInfoAllOf.  # noqa: E501


        :return: The document_thumbnail_element_id of this BTDocumentInfoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._document_thumbnail_element_id

    @document_thumbnail_element_id.setter
    def document_thumbnail_element_id(self, document_thumbnail_element_id):
        """Sets the document_thumbnail_element_id of this BTDocumentInfoAllOf.


        :param document_thumbnail_element_id: The document_thumbnail_element_id of this BTDocumentInfoAllOf.  # noqa: E501
        :type: str
        """

        self._document_thumbnail_element_id = document_thumbnail_element_id

    @property
    def duplicate_name_violation_error(self):
        """Gets the duplicate_name_violation_error of this BTDocumentInfoAllOf.  # noqa: E501


        :return: The duplicate_name_violation_error of this BTDocumentInfoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._duplicate_name_violation_error

    @duplicate_name_violation_error.setter
    def duplicate_name_violation_error(self, duplicate_name_violation_error):
        """Sets the duplicate_name_violation_error of this BTDocumentInfoAllOf.


        :param duplicate_name_violation_error: The duplicate_name_violation_error of this BTDocumentInfoAllOf.  # noqa: E501
        :type: str
        """

        self._duplicate_name_violation_error = duplicate_name_violation_error

    @property
    def beta_capability_ids(self):
        """Gets the beta_capability_ids of this BTDocumentInfoAllOf.  # noqa: E501


        :return: The beta_capability_ids of this BTDocumentInfoAllOf.  # noqa: E501
        :rtype: list[str]
        """
        return self._beta_capability_ids

    @beta_capability_ids.setter
    def beta_capability_ids(self, beta_capability_ids):
        """Sets the beta_capability_ids of this BTDocumentInfoAllOf.


        :param beta_capability_ids: The beta_capability_ids of this BTDocumentInfoAllOf.  # noqa: E501
        :type: list[str]
        """

        self._beta_capability_ids = beta_capability_ids

    @property
    def is_upgraded_to_latest_version(self):
        """Gets the is_upgraded_to_latest_version of this BTDocumentInfoAllOf.  # noqa: E501


        :return: The is_upgraded_to_latest_version of this BTDocumentInfoAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._is_upgraded_to_latest_version

    @is_upgraded_to_latest_version.setter
    def is_upgraded_to_latest_version(self, is_upgraded_to_latest_version):
        """Sets the is_upgraded_to_latest_version of this BTDocumentInfoAllOf.


        :param is_upgraded_to_latest_version: The is_upgraded_to_latest_version of this BTDocumentInfoAllOf.  # noqa: E501
        :type: bool
        """

        self._is_upgraded_to_latest_version = is_upgraded_to_latest_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentInfoAllOf):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCopyDocumentParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'project_id': 'str',
        'parent_id': 'str',
        'is_public': 'bool',
        'beta_capability_ids': 'list[str]',
        'owner_type_index': 'int',
        'new_name': 'str',
        'owner_id': 'str'
    }

    attribute_map = {
        'project_id': 'projectId',
        'parent_id': 'parentId',
        'is_public': 'isPublic',
        'beta_capability_ids': 'betaCapabilityIds',
        'owner_type_index': 'ownerTypeIndex',
        'new_name': 'newName',
        'owner_id': 'ownerId'
    }

    def __init__(self, project_id=None, parent_id=None, is_public=None, beta_capability_ids=None, owner_type_index=None, new_name=None, owner_id=None):  # noqa: E501
        """BTCopyDocumentParams - a model defined in OpenAPI"""  # noqa: E501

        self._project_id = None
        self._parent_id = None
        self._is_public = None
        self._beta_capability_ids = None
        self._owner_type_index = None
        self._new_name = None
        self._owner_id = None
        self.discriminator = None

        if project_id is not None:
            self.project_id = project_id
        if parent_id is not None:
            self.parent_id = parent_id
        if is_public is not None:
            self.is_public = is_public
        if beta_capability_ids is not None:
            self.beta_capability_ids = beta_capability_ids
        if owner_type_index is not None:
            self.owner_type_index = owner_type_index
        if new_name is not None:
            self.new_name = new_name
        if owner_id is not None:
            self.owner_id = owner_id

    @property
    def project_id(self):
        """Gets the project_id of this BTCopyDocumentParams.  # noqa: E501


        :return: The project_id of this BTCopyDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTCopyDocumentParams.


        :param project_id: The project_id of this BTCopyDocumentParams.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def parent_id(self):
        """Gets the parent_id of this BTCopyDocumentParams.  # noqa: E501


        :return: The parent_id of this BTCopyDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTCopyDocumentParams.


        :param parent_id: The parent_id of this BTCopyDocumentParams.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def is_public(self):
        """Gets the is_public of this BTCopyDocumentParams.  # noqa: E501


        :return: The is_public of this BTCopyDocumentParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this BTCopyDocumentParams.


        :param is_public: The is_public of this BTCopyDocumentParams.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def beta_capability_ids(self):
        """Gets the beta_capability_ids of this BTCopyDocumentParams.  # noqa: E501


        :return: The beta_capability_ids of this BTCopyDocumentParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._beta_capability_ids

    @beta_capability_ids.setter
    def beta_capability_ids(self, beta_capability_ids):
        """Sets the beta_capability_ids of this BTCopyDocumentParams.


        :param beta_capability_ids: The beta_capability_ids of this BTCopyDocumentParams.  # noqa: E501
        :type: list[str]
        """

        self._beta_capability_ids = beta_capability_ids

    @property
    def owner_type_index(self):
        """Gets the owner_type_index of this BTCopyDocumentParams.  # noqa: E501


        :return: The owner_type_index of this BTCopyDocumentParams.  # noqa: E501
        :rtype: int
        """
        return self._owner_type_index

    @owner_type_index.setter
    def owner_type_index(self, owner_type_index):
        """Sets the owner_type_index of this BTCopyDocumentParams.


        :param owner_type_index: The owner_type_index of this BTCopyDocumentParams.  # noqa: E501
        :type: int
        """

        self._owner_type_index = owner_type_index

    @property
    def new_name(self):
        """Gets the new_name of this BTCopyDocumentParams.  # noqa: E501


        :return: The new_name of this BTCopyDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this BTCopyDocumentParams.


        :param new_name: The new_name of this BTCopyDocumentParams.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def owner_id(self):
        """Gets the owner_id of this BTCopyDocumentParams.  # noqa: E501


        :return: The owner_id of this BTCopyDocumentParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTCopyDocumentParams.


        :param owner_id: The owner_id of this BTCopyDocumentParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCopyDocumentParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTIdTranslationResultInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'target': 'list[str]',
        'source': 'str',
        'status': 'str'
    }

    attribute_map = {
        'target': 'target',
        'source': 'source',
        'status': 'status'
    }

    def __init__(self, target=None, source=None, status=None):  # noqa: E501
        """BTIdTranslationResultInfo - a model defined in OpenAPI"""  # noqa: E501

        self._target = None
        self._source = None
        self._status = None
        self.discriminator = None

        if target is not None:
            self.target = target
        if source is not None:
            self.source = source
        if status is not None:
            self.status = status

    @property
    def target(self):
        """Gets the target of this BTIdTranslationResultInfo.  # noqa: E501


        :return: The target of this BTIdTranslationResultInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this BTIdTranslationResultInfo.


        :param target: The target of this BTIdTranslationResultInfo.  # noqa: E501
        :type: list[str]
        """

        self._target = target

    @property
    def source(self):
        """Gets the source of this BTIdTranslationResultInfo.  # noqa: E501


        :return: The source of this BTIdTranslationResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this BTIdTranslationResultInfo.


        :param source: The source of this BTIdTranslationResultInfo.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def status(self):
        """Gets the status of this BTIdTranslationResultInfo.  # noqa: E501


        :return: The status of this BTIdTranslationResultInfo.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BTIdTranslationResultInfo.


        :param status: The status of this BTIdTranslationResultInfo.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTIdTranslationResultInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""INSERT TRANSFORMED INSTANCES INTO AN ASSEMBLY
"""

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement
from onshape_client.oas import models
import time
import json
import os.path

client = Client()

# Turn the URL into an "OnshapeElement"
url = "https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/aaa25d18038e06f0b2964e2d/e/69c9eedda86512966b20bc90"
cube = OnshapeElement(url, client=client)

create_doc_params = models.bt_document_params.BTDocumentParams(name="Insert Transformed Instances Sample")
create_doc_response = client.documents_api.create11(create_doc_params)
documents_reponse = client.documents_api.get_documents()
assembly_document = documents_reponse


from onshape_client.onshape_url import ConfiguredOnshapeElement
from onshape_client.client import Client

url = "https://cad.onshape.com/documents/35d50220cc32c1d746f6da49/w/dab43002ae070e551794be67/e/b859b39b360eba3ab94b0ca5"

cube = ConfiguredOnshapeElement(url, client=Client.get_client())


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Discriminator(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'property_name': 'str',
        'mapping': 'dict(str, str)'
    }

    attribute_map = {
        'property_name': 'propertyName',
        'mapping': 'mapping'
    }

    def __init__(self, property_name=None, mapping=None):  # noqa: E501
        """Discriminator - a model defined in OpenAPI"""  # noqa: E501

        self._property_name = None
        self._mapping = None
        self.discriminator = None

        if property_name is not None:
            self.property_name = property_name
        if mapping is not None:
            self.mapping = mapping

    @property
    def property_name(self):
        """Gets the property_name of this Discriminator.  # noqa: E501


        :return: The property_name of this Discriminator.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this Discriminator.


        :param property_name: The property_name of this Discriminator.  # noqa: E501
        :type: str
        """

        self._property_name = property_name

    @property
    def mapping(self):
        """Gets the mapping of this Discriminator.  # noqa: E501


        :return: The mapping of this Discriminator.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._mapping

    @mapping.setter
    def mapping(self, mapping):
        """Sets the mapping of this Discriminator.


        :param mapping: The mapping of this Discriminator.  # noqa: E501
        :type: dict(str, str)
        """

        self._mapping = mapping

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Discriminator):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Get all the FeatureScripts within a given document and save them to a local folder.
"""

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement
from onshape_client.oas.models.bt_translate_format_params import BTTranslateFormatParams
import time
import json
import os.path
from pathlib import Path

client = Client()

# We're saving these files to the home directory ("~")
client.configuration.temp_folder_path = os.path.expanduser("~")

# Turn the URL into an "OnshapeElement"
url = "https://cad.onshape.com/documents/ea1c0fef91272adff0cc4b41/w/65efb40b6df7b9206b2a10b5/e/6921aecc8424c978fe8c78ce"
cube = OnshapeElement(url, client=client)

my_elements = client.documents_api.get_elements3(cube.did, cube.wvm, cube.wvmid)
for element in my_elements:
    if element.element_type == 'FEATURESTUDIO' :
        fs_contents = client.feature_studios_api.get_feature_studio_contents1(cube.did, cube.wvm, cube.wvmid, element.id)
        file_path = Path(__file__).parent / 'tmp'/("{name}::{id}.fs".format(name=element.name, id=element.id))
        file = file_path.open(mode='w')
        file.write(fs_contents.contents)
        file.close()


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBoundingBoxParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'part_query': 'str',
        'part_id': 'str',
        'include_wire_bodies': 'bool',
        'display_state_id': 'str',
        'explosion_id': 'str',
        'element_microversion_id': 'str',
        'include_hidden': 'bool',
        'sketch_id': 'str',
        'workspace_id': 'str',
        'element_id': 'str',
        'document_id': 'str'
    }

    attribute_map = {
        'part_query': 'partQuery',
        'part_id': 'partId',
        'include_wire_bodies': 'includeWireBodies',
        'display_state_id': 'displayStateId',
        'explosion_id': 'explosionId',
        'element_microversion_id': 'elementMicroversionId',
        'include_hidden': 'includeHidden',
        'sketch_id': 'sketchId',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'document_id': 'documentId'
    }

    def __init__(self, part_query=None, part_id=None, include_wire_bodies=None, display_state_id=None, explosion_id=None, element_microversion_id=None, include_hidden=None, sketch_id=None, workspace_id=None, element_id=None, document_id=None):  # noqa: E501
        """BTBoundingBoxParams - a model defined in OpenAPI"""  # noqa: E501

        self._part_query = None
        self._part_id = None
        self._include_wire_bodies = None
        self._display_state_id = None
        self._explosion_id = None
        self._element_microversion_id = None
        self._include_hidden = None
        self._sketch_id = None
        self._workspace_id = None
        self._element_id = None
        self._document_id = None
        self.discriminator = None

        if part_query is not None:
            self.part_query = part_query
        if part_id is not None:
            self.part_id = part_id
        if include_wire_bodies is not None:
            self.include_wire_bodies = include_wire_bodies
        if display_state_id is not None:
            self.display_state_id = display_state_id
        if explosion_id is not None:
            self.explosion_id = explosion_id
        if element_microversion_id is not None:
            self.element_microversion_id = element_microversion_id
        if include_hidden is not None:
            self.include_hidden = include_hidden
        if sketch_id is not None:
            self.sketch_id = sketch_id
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if document_id is not None:
            self.document_id = document_id

    @property
    def part_query(self):
        """Gets the part_query of this BTBoundingBoxParams.  # noqa: E501


        :return: The part_query of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._part_query

    @part_query.setter
    def part_query(self, part_query):
        """Sets the part_query of this BTBoundingBoxParams.


        :param part_query: The part_query of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._part_query = part_query

    @property
    def part_id(self):
        """Gets the part_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The part_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTBoundingBoxParams.


        :param part_id: The part_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def include_wire_bodies(self):
        """Gets the include_wire_bodies of this BTBoundingBoxParams.  # noqa: E501


        :return: The include_wire_bodies of this BTBoundingBoxParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_wire_bodies

    @include_wire_bodies.setter
    def include_wire_bodies(self, include_wire_bodies):
        """Sets the include_wire_bodies of this BTBoundingBoxParams.


        :param include_wire_bodies: The include_wire_bodies of this BTBoundingBoxParams.  # noqa: E501
        :type: bool
        """

        self._include_wire_bodies = include_wire_bodies

    @property
    def display_state_id(self):
        """Gets the display_state_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The display_state_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._display_state_id

    @display_state_id.setter
    def display_state_id(self, display_state_id):
        """Sets the display_state_id of this BTBoundingBoxParams.


        :param display_state_id: The display_state_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._display_state_id = display_state_id

    @property
    def explosion_id(self):
        """Gets the explosion_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The explosion_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._explosion_id

    @explosion_id.setter
    def explosion_id(self, explosion_id):
        """Sets the explosion_id of this BTBoundingBoxParams.


        :param explosion_id: The explosion_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._explosion_id = explosion_id

    @property
    def element_microversion_id(self):
        """Gets the element_microversion_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The element_microversion_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._element_microversion_id

    @element_microversion_id.setter
    def element_microversion_id(self, element_microversion_id):
        """Sets the element_microversion_id of this BTBoundingBoxParams.


        :param element_microversion_id: The element_microversion_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._element_microversion_id = element_microversion_id

    @property
    def include_hidden(self):
        """Gets the include_hidden of this BTBoundingBoxParams.  # noqa: E501


        :return: The include_hidden of this BTBoundingBoxParams.  # noqa: E501
        :rtype: bool
        """
        return self._include_hidden

    @include_hidden.setter
    def include_hidden(self, include_hidden):
        """Sets the include_hidden of this BTBoundingBoxParams.


        :param include_hidden: The include_hidden of this BTBoundingBoxParams.  # noqa: E501
        :type: bool
        """

        self._include_hidden = include_hidden

    @property
    def sketch_id(self):
        """Gets the sketch_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The sketch_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._sketch_id

    @sketch_id.setter
    def sketch_id(self, sketch_id):
        """Sets the sketch_id of this BTBoundingBoxParams.


        :param sketch_id: The sketch_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._sketch_id = sketch_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The workspace_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTBoundingBoxParams.


        :param workspace_id: The workspace_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The element_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTBoundingBoxParams.


        :param element_id: The element_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def document_id(self):
        """Gets the document_id of this BTBoundingBoxParams.  # noqa: E501


        :return: The document_id of this BTBoundingBoxParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTBoundingBoxParams.


        :param document_id: The document_id of this BTBoundingBoxParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBoundingBoxParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTRefreshReleaseParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'workspace_id': 'str',
        'create_new': 'bool',
        'update_params': 'BTUpdateReleasePackageParams',
        'workflow_id': 'str'
    }

    attribute_map = {
        'workspace_id': 'workspaceId',
        'create_new': 'createNew',
        'update_params': 'updateParams',
        'workflow_id': 'workflowId'
    }

    def __init__(self, workspace_id=None, create_new=None, update_params=None, workflow_id=None):  # noqa: E501
        """BTRefreshReleaseParams - a model defined in OpenAPI"""  # noqa: E501

        self._workspace_id = None
        self._create_new = None
        self._update_params = None
        self._workflow_id = None
        self.discriminator = None

        if workspace_id is not None:
            self.workspace_id = workspace_id
        if create_new is not None:
            self.create_new = create_new
        if update_params is not None:
            self.update_params = update_params
        if workflow_id is not None:
            self.workflow_id = workflow_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTRefreshReleaseParams.  # noqa: E501


        :return: The workspace_id of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTRefreshReleaseParams.


        :param workspace_id: The workspace_id of this BTRefreshReleaseParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def create_new(self):
        """Gets the create_new of this BTRefreshReleaseParams.  # noqa: E501


        :return: The create_new of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: bool
        """
        return self._create_new

    @create_new.setter
    def create_new(self, create_new):
        """Sets the create_new of this BTRefreshReleaseParams.


        :param create_new: The create_new of this BTRefreshReleaseParams.  # noqa: E501
        :type: bool
        """

        self._create_new = create_new

    @property
    def update_params(self):
        """Gets the update_params of this BTRefreshReleaseParams.  # noqa: E501


        :return: The update_params of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: BTUpdateReleasePackageParams
        """
        return self._update_params

    @update_params.setter
    def update_params(self, update_params):
        """Sets the update_params of this BTRefreshReleaseParams.


        :param update_params: The update_params of this BTRefreshReleaseParams.  # noqa: E501
        :type: BTUpdateReleasePackageParams
        """

        self._update_params = update_params

    @property
    def workflow_id(self):
        """Gets the workflow_id of this BTRefreshReleaseParams.  # noqa: E501


        :return: The workflow_id of this BTRefreshReleaseParams.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this BTRefreshReleaseParams.


        :param workflow_id: The workflow_id of this BTRefreshReleaseParams.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTRefreshReleaseParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCopyElementParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'document_id_source': 'str',
        'workspace_id_source': 'str',
        'element_id_source': 'str',
        'anchor_element_id': 'str',
        'is_group_anchor': 'bool'
    }

    attribute_map = {
        'document_id_source': 'documentIdSource',
        'workspace_id_source': 'workspaceIdSource',
        'element_id_source': 'elementIdSource',
        'anchor_element_id': 'anchorElementId',
        'is_group_anchor': 'isGroupAnchor'
    }

    def __init__(self, document_id_source=None, workspace_id_source=None, element_id_source=None, anchor_element_id=None, is_group_anchor=None):  # noqa: E501
        """BTCopyElementParams - a model defined in OpenAPI"""  # noqa: E501

        self._document_id_source = None
        self._workspace_id_source = None
        self._element_id_source = None
        self._anchor_element_id = None
        self._is_group_anchor = None
        self.discriminator = None

        if document_id_source is not None:
            self.document_id_source = document_id_source
        if workspace_id_source is not None:
            self.workspace_id_source = workspace_id_source
        if element_id_source is not None:
            self.element_id_source = element_id_source
        if anchor_element_id is not None:
            self.anchor_element_id = anchor_element_id
        if is_group_anchor is not None:
            self.is_group_anchor = is_group_anchor

    @property
    def document_id_source(self):
        """Gets the document_id_source of this BTCopyElementParams.  # noqa: E501


        :return: The document_id_source of this BTCopyElementParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id_source

    @document_id_source.setter
    def document_id_source(self, document_id_source):
        """Sets the document_id_source of this BTCopyElementParams.


        :param document_id_source: The document_id_source of this BTCopyElementParams.  # noqa: E501
        :type: str
        """

        self._document_id_source = document_id_source

    @property
    def workspace_id_source(self):
        """Gets the workspace_id_source of this BTCopyElementParams.  # noqa: E501


        :return: The workspace_id_source of this BTCopyElementParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id_source

    @workspace_id_source.setter
    def workspace_id_source(self, workspace_id_source):
        """Sets the workspace_id_source of this BTCopyElementParams.


        :param workspace_id_source: The workspace_id_source of this BTCopyElementParams.  # noqa: E501
        :type: str
        """

        self._workspace_id_source = workspace_id_source

    @property
    def element_id_source(self):
        """Gets the element_id_source of this BTCopyElementParams.  # noqa: E501


        :return: The element_id_source of this BTCopyElementParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id_source

    @element_id_source.setter
    def element_id_source(self, element_id_source):
        """Sets the element_id_source of this BTCopyElementParams.


        :param element_id_source: The element_id_source of this BTCopyElementParams.  # noqa: E501
        :type: str
        """

        self._element_id_source = element_id_source

    @property
    def anchor_element_id(self):
        """Gets the anchor_element_id of this BTCopyElementParams.  # noqa: E501


        :return: The anchor_element_id of this BTCopyElementParams.  # noqa: E501
        :rtype: str
        """
        return self._anchor_element_id

    @anchor_element_id.setter
    def anchor_element_id(self, anchor_element_id):
        """Sets the anchor_element_id of this BTCopyElementParams.


        :param anchor_element_id: The anchor_element_id of this BTCopyElementParams.  # noqa: E501
        :type: str
        """

        self._anchor_element_id = anchor_element_id

    @property
    def is_group_anchor(self):
        """Gets the is_group_anchor of this BTCopyElementParams.  # noqa: E501


        :return: The is_group_anchor of this BTCopyElementParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_group_anchor

    @is_group_anchor.setter
    def is_group_anchor(self, is_group_anchor):
        """Sets the is_group_anchor of this BTCopyElementParams.


        :param is_group_anchor: The is_group_anchor of this BTCopyElementParams.  # noqa: E501
        :type: bool
        """

        self._is_group_anchor = is_group_anchor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCopyElementParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPartMaterialInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'display_name': 'str',
        'library_name': 'str',
        'library_reference': 'BTExternalElementReferenceInfo',
        'properties': 'list[BTPartMaterialPropertyInfo]'
    }

    attribute_map = {
        'id': 'id',
        'display_name': 'displayName',
        'library_name': 'libraryName',
        'library_reference': 'libraryReference',
        'properties': 'properties'
    }

    def __init__(self, id=None, display_name=None, library_name=None, library_reference=None, properties=None):  # noqa: E501
        """BTPartMaterialInfo - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._display_name = None
        self._library_name = None
        self._library_reference = None
        self._properties = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if display_name is not None:
            self.display_name = display_name
        if library_name is not None:
            self.library_name = library_name
        if library_reference is not None:
            self.library_reference = library_reference
        if properties is not None:
            self.properties = properties

    @property
    def id(self):
        """Gets the id of this BTPartMaterialInfo.  # noqa: E501


        :return: The id of this BTPartMaterialInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTPartMaterialInfo.


        :param id: The id of this BTPartMaterialInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def display_name(self):
        """Gets the display_name of this BTPartMaterialInfo.  # noqa: E501


        :return: The display_name of this BTPartMaterialInfo.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BTPartMaterialInfo.


        :param display_name: The display_name of this BTPartMaterialInfo.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def library_name(self):
        """Gets the library_name of this BTPartMaterialInfo.  # noqa: E501


        :return: The library_name of this BTPartMaterialInfo.  # noqa: E501
        :rtype: str
        """
        return self._library_name

    @library_name.setter
    def library_name(self, library_name):
        """Sets the library_name of this BTPartMaterialInfo.


        :param library_name: The library_name of this BTPartMaterialInfo.  # noqa: E501
        :type: str
        """

        self._library_name = library_name

    @property
    def library_reference(self):
        """Gets the library_reference of this BTPartMaterialInfo.  # noqa: E501


        :return: The library_reference of this BTPartMaterialInfo.  # noqa: E501
        :rtype: BTExternalElementReferenceInfo
        """
        return self._library_reference

    @library_reference.setter
    def library_reference(self, library_reference):
        """Sets the library_reference of this BTPartMaterialInfo.


        :param library_reference: The library_reference of this BTPartMaterialInfo.  # noqa: E501
        :type: BTExternalElementReferenceInfo
        """

        self._library_reference = library_reference

    @property
    def properties(self):
        """Gets the properties of this BTPartMaterialInfo.  # noqa: E501


        :return: The properties of this BTPartMaterialInfo.  # noqa: E501
        :rtype: list[BTPartMaterialPropertyInfo]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BTPartMaterialInfo.


        :param properties: The properties of this BTPartMaterialInfo.  # noqa: E501
        :type: list[BTPartMaterialPropertyInfo]
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPartMaterialInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTFolderInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parent_id': 'str',
        'permission_set': 'object',
        'trash': 'bool',
        'can_unshare': 'bool',
        'active': 'bool',
        'trashed_at': 'datetime',
        'is_orphaned': 'bool'
    }

    attribute_map = {
        'parent_id': 'parentId',
        'permission_set': 'permissionSet',
        'trash': 'trash',
        'can_unshare': 'canUnshare',
        'active': 'active',
        'trashed_at': 'trashedAt',
        'is_orphaned': 'isOrphaned'
    }

    def __init__(self, parent_id=None, permission_set=None, trash=None, can_unshare=None, active=None, trashed_at=None, is_orphaned=None):  # noqa: E501
        """BTFolderInfo - a model defined in OpenAPI"""  # noqa: E501

        self._parent_id = None
        self._permission_set = None
        self._trash = None
        self._can_unshare = None
        self._active = None
        self._trashed_at = None
        self._is_orphaned = None
        self.discriminator = None

        if parent_id is not None:
            self.parent_id = parent_id
        if permission_set is not None:
            self.permission_set = permission_set
        if trash is not None:
            self.trash = trash
        if can_unshare is not None:
            self.can_unshare = can_unshare
        if active is not None:
            self.active = active
        if trashed_at is not None:
            self.trashed_at = trashed_at
        if is_orphaned is not None:
            self.is_orphaned = is_orphaned

    @property
    def parent_id(self):
        """Gets the parent_id of this BTFolderInfo.  # noqa: E501


        :return: The parent_id of this BTFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTFolderInfo.


        :param parent_id: The parent_id of this BTFolderInfo.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def permission_set(self):
        """Gets the permission_set of this BTFolderInfo.  # noqa: E501


        :return: The permission_set of this BTFolderInfo.  # noqa: E501
        :rtype: object
        """
        return self._permission_set

    @permission_set.setter
    def permission_set(self, permission_set):
        """Sets the permission_set of this BTFolderInfo.


        :param permission_set: The permission_set of this BTFolderInfo.  # noqa: E501
        :type: object
        """

        self._permission_set = permission_set

    @property
    def trash(self):
        """Gets the trash of this BTFolderInfo.  # noqa: E501


        :return: The trash of this BTFolderInfo.  # noqa: E501
        :rtype: bool
        """
        return self._trash

    @trash.setter
    def trash(self, trash):
        """Sets the trash of this BTFolderInfo.


        :param trash: The trash of this BTFolderInfo.  # noqa: E501
        :type: bool
        """

        self._trash = trash

    @property
    def can_unshare(self):
        """Gets the can_unshare of this BTFolderInfo.  # noqa: E501


        :return: The can_unshare of this BTFolderInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_unshare

    @can_unshare.setter
    def can_unshare(self, can_unshare):
        """Sets the can_unshare of this BTFolderInfo.


        :param can_unshare: The can_unshare of this BTFolderInfo.  # noqa: E501
        :type: bool
        """

        self._can_unshare = can_unshare

    @property
    def active(self):
        """Gets the active of this BTFolderInfo.  # noqa: E501


        :return: The active of this BTFolderInfo.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this BTFolderInfo.


        :param active: The active of this BTFolderInfo.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def trashed_at(self):
        """Gets the trashed_at of this BTFolderInfo.  # noqa: E501


        :return: The trashed_at of this BTFolderInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._trashed_at

    @trashed_at.setter
    def trashed_at(self, trashed_at):
        """Sets the trashed_at of this BTFolderInfo.


        :param trashed_at: The trashed_at of this BTFolderInfo.  # noqa: E501
        :type: datetime
        """

        self._trashed_at = trashed_at

    @property
    def is_orphaned(self):
        """Gets the is_orphaned of this BTFolderInfo.  # noqa: E501


        :return: The is_orphaned of this BTFolderInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_orphaned

    @is_orphaned.setter
    def is_orphaned(self, is_orphaned):
        """Sets the is_orphaned of this BTFolderInfo.


        :param is_orphaned: The is_orphaned of this BTFolderInfo.  # noqa: E501
        :type: bool
        """

        self._is_orphaned = is_orphaned

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTFolderInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTInheritedAclInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'object_name': 'str',
        'shared_with_support': 'bool',
        'entries': 'list[BTAclEntryInfo]',
        'object_id': 'str',
        'object_type': 'int',
        'visibility': 'str',
        'public': 'bool',
        'owner': 'BTOwnerInfo',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str',
        'name': 'str'
    }

    attribute_map = {
        'object_name': 'objectName',
        'shared_with_support': 'sharedWithSupport',
        'entries': 'entries',
        'object_id': 'objectId',
        'object_type': 'objectType',
        'visibility': 'visibility',
        'public': 'public',
        'owner': 'owner',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef',
        'name': 'name'
    }

    def __init__(self, object_name=None, shared_with_support=None, entries=None, object_id=None, object_type=None, visibility=None, public=None, owner=None, id=None, href=None, view_ref=None, name=None):  # noqa: E501
        """BTInheritedAclInfo - a model defined in OpenAPI"""  # noqa: E501

        self._object_name = None
        self._shared_with_support = None
        self._entries = None
        self._object_id = None
        self._object_type = None
        self._visibility = None
        self._public = None
        self._owner = None
        self._id = None
        self._href = None
        self._view_ref = None
        self._name = None
        self.discriminator = None

        if object_name is not None:
            self.object_name = object_name
        if shared_with_support is not None:
            self.shared_with_support = shared_with_support
        if entries is not None:
            self.entries = entries
        if object_id is not None:
            self.object_id = object_id
        if object_type is not None:
            self.object_type = object_type
        if visibility is not None:
            self.visibility = visibility
        if public is not None:
            self.public = public
        if owner is not None:
            self.owner = owner
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref
        if name is not None:
            self.name = name

    @property
    def object_name(self):
        """Gets the object_name of this BTInheritedAclInfo.  # noqa: E501


        :return: The object_name of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """Sets the object_name of this BTInheritedAclInfo.


        :param object_name: The object_name of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._object_name = object_name

    @property
    def shared_with_support(self):
        """Gets the shared_with_support of this BTInheritedAclInfo.  # noqa: E501


        :return: The shared_with_support of this BTInheritedAclInfo.  # noqa: E501
        :rtype: bool
        """
        return self._shared_with_support

    @shared_with_support.setter
    def shared_with_support(self, shared_with_support):
        """Sets the shared_with_support of this BTInheritedAclInfo.


        :param shared_with_support: The shared_with_support of this BTInheritedAclInfo.  # noqa: E501
        :type: bool
        """

        self._shared_with_support = shared_with_support

    @property
    def entries(self):
        """Gets the entries of this BTInheritedAclInfo.  # noqa: E501


        :return: The entries of this BTInheritedAclInfo.  # noqa: E501
        :rtype: list[BTAclEntryInfo]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this BTInheritedAclInfo.


        :param entries: The entries of this BTInheritedAclInfo.  # noqa: E501
        :type: list[BTAclEntryInfo]
        """

        self._entries = entries

    @property
    def object_id(self):
        """Gets the object_id of this BTInheritedAclInfo.  # noqa: E501


        :return: The object_id of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this BTInheritedAclInfo.


        :param object_id: The object_id of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def object_type(self):
        """Gets the object_type of this BTInheritedAclInfo.  # noqa: E501


        :return: The object_type of this BTInheritedAclInfo.  # noqa: E501
        :rtype: int
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this BTInheritedAclInfo.


        :param object_type: The object_type of this BTInheritedAclInfo.  # noqa: E501
        :type: int
        """

        self._object_type = object_type

    @property
    def visibility(self):
        """Gets the visibility of this BTInheritedAclInfo.  # noqa: E501


        :return: The visibility of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this BTInheritedAclInfo.


        :param visibility: The visibility of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def public(self):
        """Gets the public of this BTInheritedAclInfo.  # noqa: E501


        :return: The public of this BTInheritedAclInfo.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this BTInheritedAclInfo.


        :param public: The public of this BTInheritedAclInfo.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def owner(self):
        """Gets the owner of this BTInheritedAclInfo.  # noqa: E501


        :return: The owner of this BTInheritedAclInfo.  # noqa: E501
        :rtype: BTOwnerInfo
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this BTInheritedAclInfo.


        :param owner: The owner of this BTInheritedAclInfo.  # noqa: E501
        :type: BTOwnerInfo
        """

        self._owner = owner

    @property
    def id(self):
        """Gets the id of this BTInheritedAclInfo.  # noqa: E501


        :return: The id of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTInheritedAclInfo.


        :param id: The id of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTInheritedAclInfo.  # noqa: E501


        :return: The href of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTInheritedAclInfo.


        :param href: The href of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTInheritedAclInfo.  # noqa: E501


        :return: The view_ref of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTInheritedAclInfo.


        :param view_ref: The view_ref of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    @property
    def name(self):
        """Gets the name of this BTInheritedAclInfo.  # noqa: E501


        :return: The name of this BTInheritedAclInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTInheritedAclInfo.


        :param name: The name of this BTInheritedAclInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTInheritedAclInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDiffInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_id': 'str',
        'changes': 'dict(str, BTDiffInfo)',
        'geometry_change_messages': 'list[str]',
        'source_value': 'str',
        'target_value': 'str',
        'target_id': 'str',
        'entity_type': 'str',
        'type': 'str'
    }

    attribute_map = {
        'source_id': 'sourceId',
        'changes': 'changes',
        'geometry_change_messages': 'geometryChangeMessages',
        'source_value': 'sourceValue',
        'target_value': 'targetValue',
        'target_id': 'targetId',
        'entity_type': 'entityType',
        'type': 'type'
    }

    def __init__(self, source_id=None, changes=None, geometry_change_messages=None, source_value=None, target_value=None, target_id=None, entity_type=None, type=None):  # noqa: E501
        """BTDiffInfo - a model defined in OpenAPI"""  # noqa: E501

        self._source_id = None
        self._changes = None
        self._geometry_change_messages = None
        self._source_value = None
        self._target_value = None
        self._target_id = None
        self._entity_type = None
        self._type = None
        self.discriminator = None

        if source_id is not None:
            self.source_id = source_id
        if changes is not None:
            self.changes = changes
        if geometry_change_messages is not None:
            self.geometry_change_messages = geometry_change_messages
        if source_value is not None:
            self.source_value = source_value
        if target_value is not None:
            self.target_value = target_value
        if target_id is not None:
            self.target_id = target_id
        if entity_type is not None:
            self.entity_type = entity_type
        if type is not None:
            self.type = type

    @property
    def source_id(self):
        """Gets the source_id of this BTDiffInfo.  # noqa: E501


        :return: The source_id of this BTDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this BTDiffInfo.


        :param source_id: The source_id of this BTDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_id = source_id

    @property
    def changes(self):
        """Gets the changes of this BTDiffInfo.  # noqa: E501


        :return: The changes of this BTDiffInfo.  # noqa: E501
        :rtype: dict(str, BTDiffInfo)
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """Sets the changes of this BTDiffInfo.


        :param changes: The changes of this BTDiffInfo.  # noqa: E501
        :type: dict(str, BTDiffInfo)
        """

        self._changes = changes

    @property
    def geometry_change_messages(self):
        """Gets the geometry_change_messages of this BTDiffInfo.  # noqa: E501


        :return: The geometry_change_messages of this BTDiffInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._geometry_change_messages

    @geometry_change_messages.setter
    def geometry_change_messages(self, geometry_change_messages):
        """Sets the geometry_change_messages of this BTDiffInfo.


        :param geometry_change_messages: The geometry_change_messages of this BTDiffInfo.  # noqa: E501
        :type: list[str]
        """

        self._geometry_change_messages = geometry_change_messages

    @property
    def source_value(self):
        """Gets the source_value of this BTDiffInfo.  # noqa: E501


        :return: The source_value of this BTDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_value

    @source_value.setter
    def source_value(self, source_value):
        """Sets the source_value of this BTDiffInfo.


        :param source_value: The source_value of this BTDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_value = source_value

    @property
    def target_value(self):
        """Gets the target_value of this BTDiffInfo.  # noqa: E501


        :return: The target_value of this BTDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_value

    @target_value.setter
    def target_value(self, target_value):
        """Sets the target_value of this BTDiffInfo.


        :param target_value: The target_value of this BTDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_value = target_value

    @property
    def target_id(self):
        """Gets the target_id of this BTDiffInfo.  # noqa: E501


        :return: The target_id of this BTDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this BTDiffInfo.


        :param target_id: The target_id of this BTDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def entity_type(self):
        """Gets the entity_type of this BTDiffInfo.  # noqa: E501


        :return: The entity_type of this BTDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this BTDiffInfo.


        :param entity_type: The entity_type of this BTDiffInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["PARTS", "SKETCHES", "POINTS", "MATE_CONNECTORS", "PLANES", "CURVES", "SURFACES"]  # noqa: E501
        if entity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def type(self):
        """Gets the type of this BTDiffInfo.  # noqa: E501


        :return: The type of this BTDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTDiffInfo.


        :param type: The type of this BTDiffInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "MOVED", "MODIFIED", "MOVED_AND_MODIFIED", "ADDED", "DELETED", "UNKNOWN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDiffInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.103
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPartQueryParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'configuration': 'str',
        'queries': 'list[str]',
        'link_document_id': 'str'
    }

    attribute_map = {
        'configuration': 'configuration',
        'queries': 'queries',
        'link_document_id': 'linkDocumentId'
    }

    def __init__(self, configuration=None, queries=None, link_document_id=None):  # noqa: E501
        """BTPartQueryParams - a model defined in OpenAPI"""  # noqa: E501

        self._configuration = None
        self._queries = None
        self._link_document_id = None
        self.discriminator = None

        if configuration is not None:
            self.configuration = configuration
        if queries is not None:
            self.queries = queries
        if link_document_id is not None:
            self.link_document_id = link_document_id

    @property
    def configuration(self):
        """Gets the configuration of this BTPartQueryParams.  # noqa: E501


        :return: The configuration of this BTPartQueryParams.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTPartQueryParams.


        :param configuration: The configuration of this BTPartQueryParams.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def queries(self):
        """Gets the queries of this BTPartQueryParams.  # noqa: E501


        :return: The queries of this BTPartQueryParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._queries

    @queries.setter
    def queries(self, queries):
        """Sets the queries of this BTPartQueryParams.


        :param queries: The queries of this BTPartQueryParams.  # noqa: E501
        :type: list[str]
        """

        self._queries = queries

    @property
    def link_document_id(self):
        """Gets the link_document_id of this BTPartQueryParams.  # noqa: E501


        :return: The link_document_id of this BTPartQueryParams.  # noqa: E501
        :rtype: str
        """
        return self._link_document_id

    @link_document_id.setter
    def link_document_id(self, link_document_id):
        """Sets the link_document_id of this BTPartQueryParams.


        :param link_document_id: The link_document_id of this BTPartQueryParams.  # noqa: E501
        :type: str
        """

        self._link_document_id = link_document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPartQueryParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMSketchConstraint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'driven_dimension': 'bool',
        'constraint_type': 'str',
        'has_offset_data1': 'bool',
        'offset_orientation1': 'bool',
        'offset_distance1': 'float',
        'has_offset_data2': 'bool',
        'offset_orientation2': 'bool',
        'offset_distance2': 'float',
        'has_pierce_parameter': 'bool',
        'pierce_parameter': 'float',
        'help_parameters': 'list[float]',
        'parameters': 'list[BTMParameter]',
        'namespace': 'str',
        'node_id': 'str',
        'import_microversion': 'str',
        'entity_id': 'str'
    }

    attribute_map = {
        'driven_dimension': 'drivenDimension',
        'constraint_type': 'constraintType',
        'has_offset_data1': 'hasOffsetData1',
        'offset_orientation1': 'offsetOrientation1',
        'offset_distance1': 'offsetDistance1',
        'has_offset_data2': 'hasOffsetData2',
        'offset_orientation2': 'offsetOrientation2',
        'offset_distance2': 'offsetDistance2',
        'has_pierce_parameter': 'hasPierceParameter',
        'pierce_parameter': 'pierceParameter',
        'help_parameters': 'helpParameters',
        'parameters': 'parameters',
        'namespace': 'namespace',
        'node_id': 'nodeId',
        'import_microversion': 'importMicroversion',
        'entity_id': 'entityId'
    }

    def __init__(self, driven_dimension=None, constraint_type=None, has_offset_data1=None, offset_orientation1=None, offset_distance1=None, has_offset_data2=None, offset_orientation2=None, offset_distance2=None, has_pierce_parameter=None, pierce_parameter=None, help_parameters=None, parameters=None, namespace=None, node_id=None, import_microversion=None, entity_id=None):  # noqa: E501
        """BTMSketchConstraint - a model defined in OpenAPI"""  # noqa: E501

        self._driven_dimension = None
        self._constraint_type = None
        self._has_offset_data1 = None
        self._offset_orientation1 = None
        self._offset_distance1 = None
        self._has_offset_data2 = None
        self._offset_orientation2 = None
        self._offset_distance2 = None
        self._has_pierce_parameter = None
        self._pierce_parameter = None
        self._help_parameters = None
        self._parameters = None
        self._namespace = None
        self._node_id = None
        self._import_microversion = None
        self._entity_id = None
        self.discriminator = None

        if driven_dimension is not None:
            self.driven_dimension = driven_dimension
        if constraint_type is not None:
            self.constraint_type = constraint_type
        if has_offset_data1 is not None:
            self.has_offset_data1 = has_offset_data1
        if offset_orientation1 is not None:
            self.offset_orientation1 = offset_orientation1
        if offset_distance1 is not None:
            self.offset_distance1 = offset_distance1
        if has_offset_data2 is not None:
            self.has_offset_data2 = has_offset_data2
        if offset_orientation2 is not None:
            self.offset_orientation2 = offset_orientation2
        if offset_distance2 is not None:
            self.offset_distance2 = offset_distance2
        if has_pierce_parameter is not None:
            self.has_pierce_parameter = has_pierce_parameter
        if pierce_parameter is not None:
            self.pierce_parameter = pierce_parameter
        if help_parameters is not None:
            self.help_parameters = help_parameters
        if parameters is not None:
            self.parameters = parameters
        if namespace is not None:
            self.namespace = namespace
        if node_id is not None:
            self.node_id = node_id
        if import_microversion is not None:
            self.import_microversion = import_microversion
        if entity_id is not None:
            self.entity_id = entity_id

    @property
    def driven_dimension(self):
        """Gets the driven_dimension of this BTMSketchConstraint.  # noqa: E501


        :return: The driven_dimension of this BTMSketchConstraint.  # noqa: E501
        :rtype: bool
        """
        return self._driven_dimension

    @driven_dimension.setter
    def driven_dimension(self, driven_dimension):
        """Sets the driven_dimension of this BTMSketchConstraint.


        :param driven_dimension: The driven_dimension of this BTMSketchConstraint.  # noqa: E501
        :type: bool
        """

        self._driven_dimension = driven_dimension

    @property
    def constraint_type(self):
        """Gets the constraint_type of this BTMSketchConstraint.  # noqa: E501


        :return: The constraint_type of this BTMSketchConstraint.  # noqa: E501
        :rtype: str
        """
        return self._constraint_type

    @constraint_type.setter
    def constraint_type(self, constraint_type):
        """Sets the constraint_type of this BTMSketchConstraint.


        :param constraint_type: The constraint_type of this BTMSketchConstraint.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "COINCIDENT", "PARALLEL", "VERTICAL", "HORIZONTAL", "PERPENDICULAR", "CONCENTRIC", "MIRROR", "MIDPOINT", "TANGENT", "EQUAL", "LENGTH", "DISTANCE", "ANGLE", "RADIUS", "NORMAL", "FIX", "PROJECTED", "OFFSET", "CIRCULAR_PATTERN", "PIERCE", "LINEAR_PATTERN", "MAJOR_DIAMETER", "MINOR_DIAMETER", "QUADRANT", "DIAMETER", "SILHOUETTED", "CENTERLINE_DIMENSION", "INTERSECTED", "RHO", "EQUAL_CURVATURE", "UNKNOWN"]  # noqa: E501
        if constraint_type not in allowed_values:
            raise ValueError(
                "Invalid value for `constraint_type` ({0}), must be one of {1}"  # noqa: E501
                .format(constraint_type, allowed_values)
            )

        self._constraint_type = constraint_type

    @property
    def has_offset_data1(self):
        """Gets the has_offset_data1 of this BTMSketchConstraint.  # noqa: E501


        :return: The has_offset_data1 of this BTMSketchConstraint.  # noqa: E501
        :rtype: bool
        """
        return self._has_offset_data1

    @has_offset_data1.setter
    def has_offset_data1(self, has_offset_data1):
        """Sets the has_offset_data1 of this BTMSketchConstraint.


        :param has_offset_data1: The has_offset_data1 of this BTMSketchConstraint.  # noqa: E501
        :type: bool
        """

        self._has_offset_data1 = has_offset_data1

    @property
    def offset_orientation1(self):
        """Gets the offset_orientation1 of this BTMSketchConstraint.  # noqa: E501


        :return: The offset_orientation1 of this BTMSketchConstraint.  # noqa: E501
        :rtype: bool
        """
        return self._offset_orientation1

    @offset_orientation1.setter
    def offset_orientation1(self, offset_orientation1):
        """Sets the offset_orientation1 of this BTMSketchConstraint.


        :param offset_orientation1: The offset_orientation1 of this BTMSketchConstraint.  # noqa: E501
        :type: bool
        """

        self._offset_orientation1 = offset_orientation1

    @property
    def offset_distance1(self):
        """Gets the offset_distance1 of this BTMSketchConstraint.  # noqa: E501


        :return: The offset_distance1 of this BTMSketchConstraint.  # noqa: E501
        :rtype: float
        """
        return self._offset_distance1

    @offset_distance1.setter
    def offset_distance1(self, offset_distance1):
        """Sets the offset_distance1 of this BTMSketchConstraint.


        :param offset_distance1: The offset_distance1 of this BTMSketchConstraint.  # noqa: E501
        :type: float
        """

        self._offset_distance1 = offset_distance1

    @property
    def has_offset_data2(self):
        """Gets the has_offset_data2 of this BTMSketchConstraint.  # noqa: E501


        :return: The has_offset_data2 of this BTMSketchConstraint.  # noqa: E501
        :rtype: bool
        """
        return self._has_offset_data2

    @has_offset_data2.setter
    def has_offset_data2(self, has_offset_data2):
        """Sets the has_offset_data2 of this BTMSketchConstraint.


        :param has_offset_data2: The has_offset_data2 of this BTMSketchConstraint.  # noqa: E501
        :type: bool
        """

        self._has_offset_data2 = has_offset_data2

    @property
    def offset_orientation2(self):
        """Gets the offset_orientation2 of this BTMSketchConstraint.  # noqa: E501


        :return: The offset_orientation2 of this BTMSketchConstraint.  # noqa: E501
        :rtype: bool
        """
        return self._offset_orientation2

    @offset_orientation2.setter
    def offset_orientation2(self, offset_orientation2):
        """Sets the offset_orientation2 of this BTMSketchConstraint.


        :param offset_orientation2: The offset_orientation2 of this BTMSketchConstraint.  # noqa: E501
        :type: bool
        """

        self._offset_orientation2 = offset_orientation2

    @property
    def offset_distance2(self):
        """Gets the offset_distance2 of this BTMSketchConstraint.  # noqa: E501


        :return: The offset_distance2 of this BTMSketchConstraint.  # noqa: E501
        :rtype: float
        """
        return self._offset_distance2

    @offset_distance2.setter
    def offset_distance2(self, offset_distance2):
        """Sets the offset_distance2 of this BTMSketchConstraint.


        :param offset_distance2: The offset_distance2 of this BTMSketchConstraint.  # noqa: E501
        :type: float
        """

        self._offset_distance2 = offset_distance2

    @property
    def has_pierce_parameter(self):
        """Gets the has_pierce_parameter of this BTMSketchConstraint.  # noqa: E501


        :return: The has_pierce_parameter of this BTMSketchConstraint.  # noqa: E501
        :rtype: bool
        """
        return self._has_pierce_parameter

    @has_pierce_parameter.setter
    def has_pierce_parameter(self, has_pierce_parameter):
        """Sets the has_pierce_parameter of this BTMSketchConstraint.


        :param has_pierce_parameter: The has_pierce_parameter of this BTMSketchConstraint.  # noqa: E501
        :type: bool
        """

        self._has_pierce_parameter = has_pierce_parameter

    @property
    def pierce_parameter(self):
        """Gets the pierce_parameter of this BTMSketchConstraint.  # noqa: E501


        :return: The pierce_parameter of this BTMSketchConstraint.  # noqa: E501
        :rtype: float
        """
        return self._pierce_parameter

    @pierce_parameter.setter
    def pierce_parameter(self, pierce_parameter):
        """Sets the pierce_parameter of this BTMSketchConstraint.


        :param pierce_parameter: The pierce_parameter of this BTMSketchConstraint.  # noqa: E501
        :type: float
        """

        self._pierce_parameter = pierce_parameter

    @property
    def help_parameters(self):
        """Gets the help_parameters of this BTMSketchConstraint.  # noqa: E501


        :return: The help_parameters of this BTMSketchConstraint.  # noqa: E501
        :rtype: list[float]
        """
        return self._help_parameters

    @help_parameters.setter
    def help_parameters(self, help_parameters):
        """Sets the help_parameters of this BTMSketchConstraint.


        :param help_parameters: The help_parameters of this BTMSketchConstraint.  # noqa: E501
        :type: list[float]
        """

        self._help_parameters = help_parameters

    @property
    def parameters(self):
        """Gets the parameters of this BTMSketchConstraint.  # noqa: E501


        :return: The parameters of this BTMSketchConstraint.  # noqa: E501
        :rtype: list[BTMParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this BTMSketchConstraint.


        :param parameters: The parameters of this BTMSketchConstraint.  # noqa: E501
        :type: list[BTMParameter]
        """

        self._parameters = parameters

    @property
    def namespace(self):
        """Gets the namespace of this BTMSketchConstraint.  # noqa: E501


        :return: The namespace of this BTMSketchConstraint.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BTMSketchConstraint.


        :param namespace: The namespace of this BTMSketchConstraint.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def node_id(self):
        """Gets the node_id of this BTMSketchConstraint.  # noqa: E501


        :return: The node_id of this BTMSketchConstraint.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTMSketchConstraint.


        :param node_id: The node_id of this BTMSketchConstraint.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def import_microversion(self):
        """Gets the import_microversion of this BTMSketchConstraint.  # noqa: E501


        :return: The import_microversion of this BTMSketchConstraint.  # noqa: E501
        :rtype: str
        """
        return self._import_microversion

    @import_microversion.setter
    def import_microversion(self, import_microversion):
        """Sets the import_microversion of this BTMSketchConstraint.


        :param import_microversion: The import_microversion of this BTMSketchConstraint.  # noqa: E501
        :type: str
        """

        self._import_microversion = import_microversion

    @property
    def entity_id(self):
        """Gets the entity_id of this BTMSketchConstraint.  # noqa: E501


        :return: The entity_id of this BTMSketchConstraint.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this BTMSketchConstraint.


        :param entity_id: The entity_id of this BTMSketchConstraint.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMSketchConstraint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from onshape_client.oas.api.accounts_api import AccountsApi
from onshape_client.oas.api.app_elements_api import AppElementsApi
from onshape_client.oas.api.assemblies_api import AssembliesApi
from onshape_client.oas.api.blob_elements_api import BlobElementsApi
from onshape_client.oas.api.documents_api import DocumentsApi
from onshape_client.oas.api.drawings_api import DrawingsApi
from onshape_client.oas.api.elements_api import ElementsApi
from onshape_client.oas.api.feature_studios_api import FeatureStudiosApi
from onshape_client.oas.api.metadata_api import MetadataApi
from onshape_client.oas.api.open_api_api import OpenAPIApi
from onshape_client.oas.api.part_studios_api import PartStudiosApi
from onshape_client.oas.api.parts_api import PartsApi
from onshape_client.oas.api.translations_api import TranslationsApi



"""Export a STEP file
"""

from onshape_client.client import Client
from onshape_client.oas.models.bt_translate_format_params import BTTranslateFormatParams
import time
import json
import os.path
from onshape_client.example_programs.onshape_models import cube

client = Client.get_client()

# We're saving these files to the home directory ("~")
client.configuration.temp_folder_path = os.path.expanduser("~")

# Create the params. Note there are far more params that can be specified.
params = BTTranslateFormatParams(element_id=cube.eid, format_name="STEP", store_in_document=False, configuration='edge_configuratioin=chamfered;size=0.254+meter')

# Call the client
start_time = time.time()
response = client.part_studios_api.translate_format5(cube.did, cube.wvm, cube.wvmid, cube.eid, bt_translate_format_params=params)
elapsed_time = time.time() - start_time
print('Took {} seconds to complete the translation start request.'.format(elapsed_time))

translation_id = response.id
state = response.request_state

# Long poll every 2 seconds until the translation is marked as done - alternatively you could submit a webhook
parsed_response = None

# Seconds between polls
polling_interval = 2

time_to_translate=0
while state == 'ACTIVE':
    time.sleep(polling_interval)
    time_to_translate += polling_interval
    response = client.translation_api.get_translation(translation_id, _preload_content=False)
    parsed_response = json.loads(response.data.decode("UTF-8"))
    state = parsed_response["requestState"]
    print("Still actively translating. Time thus far = {}".format(time_to_translate))

# Make the actual download when the translation is done, otherwise report the error
if state == "DONE":
    client.documents_api.download_external_data(cube.did, parsed_response["resultExternalDataIds"][0])
    print("File saved to {}. Took {} seconds to complete the translation.".format(client.configuration.temp_folder_path, time_to_translate))
else:
    print("An error ocurred on the server! Here is the response: \n" + parsed_response['failureReason'])
"""
File saved to <temp_folder_path>
"""


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMAssemblyFeature(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'node_id': 'str',
        'import_microversion': 'str',
        'name': 'str',
        'suppressed': 'bool',
        'parameters': 'list[BTMParameter]',
        'feature_id': 'str',
        'feature_type': 'str',
        'sub_features': 'list[BTMFeature]',
        'return_after_subfeatures': 'bool',
        'feature_list_field_index': 'int',
        'auxiliary_assembly_feature': 'bool',
        'occurrence_queries_from_all_configurations': 'list[BTMIndividualQueryWithOccurrenceBase]',
        'version': 'int'
    }

    attribute_map = {
        'namespace': 'namespace',
        'node_id': 'nodeId',
        'import_microversion': 'importMicroversion',
        'name': 'name',
        'suppressed': 'suppressed',
        'parameters': 'parameters',
        'feature_id': 'featureId',
        'feature_type': 'featureType',
        'sub_features': 'subFeatures',
        'return_after_subfeatures': 'returnAfterSubfeatures',
        'feature_list_field_index': 'featureListFieldIndex',
        'auxiliary_assembly_feature': 'auxiliaryAssemblyFeature',
        'occurrence_queries_from_all_configurations': 'occurrenceQueriesFromAllConfigurations',
        'version': 'version'
    }

    def __init__(self, namespace=None, node_id=None, import_microversion=None, name=None, suppressed=None, parameters=None, feature_id=None, feature_type=None, sub_features=None, return_after_subfeatures=None, feature_list_field_index=None, auxiliary_assembly_feature=None, occurrence_queries_from_all_configurations=None, version=None):  # noqa: E501
        """BTMAssemblyFeature - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._node_id = None
        self._import_microversion = None
        self._name = None
        self._suppressed = None
        self._parameters = None
        self._feature_id = None
        self._feature_type = None
        self._sub_features = None
        self._return_after_subfeatures = None
        self._feature_list_field_index = None
        self._auxiliary_assembly_feature = None
        self._occurrence_queries_from_all_configurations = None
        self._version = None
        self.discriminator = None

        if namespace is not None:
            self.namespace = namespace
        if node_id is not None:
            self.node_id = node_id
        if import_microversion is not None:
            self.import_microversion = import_microversion
        if name is not None:
            self.name = name
        if suppressed is not None:
            self.suppressed = suppressed
        if parameters is not None:
            self.parameters = parameters
        if feature_id is not None:
            self.feature_id = feature_id
        if feature_type is not None:
            self.feature_type = feature_type
        if sub_features is not None:
            self.sub_features = sub_features
        if return_after_subfeatures is not None:
            self.return_after_subfeatures = return_after_subfeatures
        if feature_list_field_index is not None:
            self.feature_list_field_index = feature_list_field_index
        if auxiliary_assembly_feature is not None:
            self.auxiliary_assembly_feature = auxiliary_assembly_feature
        if occurrence_queries_from_all_configurations is not None:
            self.occurrence_queries_from_all_configurations = occurrence_queries_from_all_configurations
        if version is not None:
            self.version = version

    @property
    def namespace(self):
        """Gets the namespace of this BTMAssemblyFeature.  # noqa: E501


        :return: The namespace of this BTMAssemblyFeature.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BTMAssemblyFeature.


        :param namespace: The namespace of this BTMAssemblyFeature.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def node_id(self):
        """Gets the node_id of this BTMAssemblyFeature.  # noqa: E501


        :return: The node_id of this BTMAssemblyFeature.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTMAssemblyFeature.


        :param node_id: The node_id of this BTMAssemblyFeature.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def import_microversion(self):
        """Gets the import_microversion of this BTMAssemblyFeature.  # noqa: E501


        :return: The import_microversion of this BTMAssemblyFeature.  # noqa: E501
        :rtype: str
        """
        return self._import_microversion

    @import_microversion.setter
    def import_microversion(self, import_microversion):
        """Sets the import_microversion of this BTMAssemblyFeature.


        :param import_microversion: The import_microversion of this BTMAssemblyFeature.  # noqa: E501
        :type: str
        """

        self._import_microversion = import_microversion

    @property
    def name(self):
        """Gets the name of this BTMAssemblyFeature.  # noqa: E501


        :return: The name of this BTMAssemblyFeature.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTMAssemblyFeature.


        :param name: The name of this BTMAssemblyFeature.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def suppressed(self):
        """Gets the suppressed of this BTMAssemblyFeature.  # noqa: E501


        :return: The suppressed of this BTMAssemblyFeature.  # noqa: E501
        :rtype: bool
        """
        return self._suppressed

    @suppressed.setter
    def suppressed(self, suppressed):
        """Sets the suppressed of this BTMAssemblyFeature.


        :param suppressed: The suppressed of this BTMAssemblyFeature.  # noqa: E501
        :type: bool
        """

        self._suppressed = suppressed

    @property
    def parameters(self):
        """Gets the parameters of this BTMAssemblyFeature.  # noqa: E501


        :return: The parameters of this BTMAssemblyFeature.  # noqa: E501
        :rtype: list[BTMParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this BTMAssemblyFeature.


        :param parameters: The parameters of this BTMAssemblyFeature.  # noqa: E501
        :type: list[BTMParameter]
        """

        self._parameters = parameters

    @property
    def feature_id(self):
        """Gets the feature_id of this BTMAssemblyFeature.  # noqa: E501


        :return: The feature_id of this BTMAssemblyFeature.  # noqa: E501
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """Sets the feature_id of this BTMAssemblyFeature.


        :param feature_id: The feature_id of this BTMAssemblyFeature.  # noqa: E501
        :type: str
        """

        self._feature_id = feature_id

    @property
    def feature_type(self):
        """Gets the feature_type of this BTMAssemblyFeature.  # noqa: E501


        :return: The feature_type of this BTMAssemblyFeature.  # noqa: E501
        :rtype: str
        """
        return self._feature_type

    @feature_type.setter
    def feature_type(self, feature_type):
        """Sets the feature_type of this BTMAssemblyFeature.


        :param feature_type: The feature_type of this BTMAssemblyFeature.  # noqa: E501
        :type: str
        """

        self._feature_type = feature_type

    @property
    def sub_features(self):
        """Gets the sub_features of this BTMAssemblyFeature.  # noqa: E501


        :return: The sub_features of this BTMAssemblyFeature.  # noqa: E501
        :rtype: list[BTMFeature]
        """
        return self._sub_features

    @sub_features.setter
    def sub_features(self, sub_features):
        """Sets the sub_features of this BTMAssemblyFeature.


        :param sub_features: The sub_features of this BTMAssemblyFeature.  # noqa: E501
        :type: list[BTMFeature]
        """

        self._sub_features = sub_features

    @property
    def return_after_subfeatures(self):
        """Gets the return_after_subfeatures of this BTMAssemblyFeature.  # noqa: E501


        :return: The return_after_subfeatures of this BTMAssemblyFeature.  # noqa: E501
        :rtype: bool
        """
        return self._return_after_subfeatures

    @return_after_subfeatures.setter
    def return_after_subfeatures(self, return_after_subfeatures):
        """Sets the return_after_subfeatures of this BTMAssemblyFeature.


        :param return_after_subfeatures: The return_after_subfeatures of this BTMAssemblyFeature.  # noqa: E501
        :type: bool
        """

        self._return_after_subfeatures = return_after_subfeatures

    @property
    def feature_list_field_index(self):
        """Gets the feature_list_field_index of this BTMAssemblyFeature.  # noqa: E501


        :return: The feature_list_field_index of this BTMAssemblyFeature.  # noqa: E501
        :rtype: int
        """
        return self._feature_list_field_index

    @feature_list_field_index.setter
    def feature_list_field_index(self, feature_list_field_index):
        """Sets the feature_list_field_index of this BTMAssemblyFeature.


        :param feature_list_field_index: The feature_list_field_index of this BTMAssemblyFeature.  # noqa: E501
        :type: int
        """

        self._feature_list_field_index = feature_list_field_index

    @property
    def auxiliary_assembly_feature(self):
        """Gets the auxiliary_assembly_feature of this BTMAssemblyFeature.  # noqa: E501


        :return: The auxiliary_assembly_feature of this BTMAssemblyFeature.  # noqa: E501
        :rtype: bool
        """
        return self._auxiliary_assembly_feature

    @auxiliary_assembly_feature.setter
    def auxiliary_assembly_feature(self, auxiliary_assembly_feature):
        """Sets the auxiliary_assembly_feature of this BTMAssemblyFeature.


        :param auxiliary_assembly_feature: The auxiliary_assembly_feature of this BTMAssemblyFeature.  # noqa: E501
        :type: bool
        """

        self._auxiliary_assembly_feature = auxiliary_assembly_feature

    @property
    def occurrence_queries_from_all_configurations(self):
        """Gets the occurrence_queries_from_all_configurations of this BTMAssemblyFeature.  # noqa: E501


        :return: The occurrence_queries_from_all_configurations of this BTMAssemblyFeature.  # noqa: E501
        :rtype: list[BTMIndividualQueryWithOccurrenceBase]
        """
        return self._occurrence_queries_from_all_configurations

    @occurrence_queries_from_all_configurations.setter
    def occurrence_queries_from_all_configurations(self, occurrence_queries_from_all_configurations):
        """Sets the occurrence_queries_from_all_configurations of this BTMAssemblyFeature.


        :param occurrence_queries_from_all_configurations: The occurrence_queries_from_all_configurations of this BTMAssemblyFeature.  # noqa: E501
        :type: list[BTMIndividualQueryWithOccurrenceBase]
        """

        self._occurrence_queries_from_all_configurations = occurrence_queries_from_all_configurations

    @property
    def version(self):
        """Gets the version of this BTMAssemblyFeature.  # noqa: E501


        :return: The version of this BTMAssemblyFeature.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BTMAssemblyFeature.


        :param version: The version of this BTMAssemblyFeature.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMAssemblyFeature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTFeatureScriptEvalCall(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'queries': 'dict(str, list[str])',
        'script': 'str',
        'source_microversion': 'str',
        'reject_microversion_skew': 'bool',
        'library_version': 'int',
        'microversion_skew': 'bool',
        'serialization_version': 'str'
    }

    attribute_map = {
        'queries': 'queries',
        'script': 'script',
        'source_microversion': 'sourceMicroversion',
        'reject_microversion_skew': 'rejectMicroversionSkew',
        'library_version': 'libraryVersion',
        'microversion_skew': 'microversionSkew',
        'serialization_version': 'serializationVersion'
    }

    def __init__(self, queries=None, script=None, source_microversion=None, reject_microversion_skew=None, library_version=None, microversion_skew=None, serialization_version=None):  # noqa: E501
        """BTFeatureScriptEvalCall - a model defined in OpenAPI"""  # noqa: E501

        self._queries = None
        self._script = None
        self._source_microversion = None
        self._reject_microversion_skew = None
        self._library_version = None
        self._microversion_skew = None
        self._serialization_version = None
        self.discriminator = None

        if queries is not None:
            self.queries = queries
        if script is not None:
            self.script = script
        if source_microversion is not None:
            self.source_microversion = source_microversion
        if reject_microversion_skew is not None:
            self.reject_microversion_skew = reject_microversion_skew
        if library_version is not None:
            self.library_version = library_version
        if microversion_skew is not None:
            self.microversion_skew = microversion_skew
        if serialization_version is not None:
            self.serialization_version = serialization_version

    @property
    def queries(self):
        """Gets the queries of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The queries of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._queries

    @queries.setter
    def queries(self, queries):
        """Sets the queries of this BTFeatureScriptEvalCall.


        :param queries: The queries of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._queries = queries

    @property
    def script(self):
        """Gets the script of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The script of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this BTFeatureScriptEvalCall.


        :param script: The script of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: str
        """

        self._script = script

    @property
    def source_microversion(self):
        """Gets the source_microversion of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The source_microversion of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: str
        """
        return self._source_microversion

    @source_microversion.setter
    def source_microversion(self, source_microversion):
        """Sets the source_microversion of this BTFeatureScriptEvalCall.


        :param source_microversion: The source_microversion of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: str
        """

        self._source_microversion = source_microversion

    @property
    def reject_microversion_skew(self):
        """Gets the reject_microversion_skew of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The reject_microversion_skew of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: bool
        """
        return self._reject_microversion_skew

    @reject_microversion_skew.setter
    def reject_microversion_skew(self, reject_microversion_skew):
        """Sets the reject_microversion_skew of this BTFeatureScriptEvalCall.


        :param reject_microversion_skew: The reject_microversion_skew of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: bool
        """

        self._reject_microversion_skew = reject_microversion_skew

    @property
    def library_version(self):
        """Gets the library_version of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The library_version of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: int
        """
        return self._library_version

    @library_version.setter
    def library_version(self, library_version):
        """Sets the library_version of this BTFeatureScriptEvalCall.


        :param library_version: The library_version of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: int
        """

        self._library_version = library_version

    @property
    def microversion_skew(self):
        """Gets the microversion_skew of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The microversion_skew of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: bool
        """
        return self._microversion_skew

    @microversion_skew.setter
    def microversion_skew(self, microversion_skew):
        """Sets the microversion_skew of this BTFeatureScriptEvalCall.


        :param microversion_skew: The microversion_skew of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: bool
        """

        self._microversion_skew = microversion_skew

    @property
    def serialization_version(self):
        """Gets the serialization_version of this BTFeatureScriptEvalCall.  # noqa: E501


        :return: The serialization_version of this BTFeatureScriptEvalCall.  # noqa: E501
        :rtype: str
        """
        return self._serialization_version

    @serialization_version.setter
    def serialization_version(self, serialization_version):
        """Sets the serialization_version of this BTFeatureScriptEvalCall.


        :param serialization_version: The serialization_version of this BTFeatureScriptEvalCall.  # noqa: E501
        :type: str
        """

        self._serialization_version = serialization_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTFeatureScriptEvalCall):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
